using Microsoft.AspNetCore.Mvc;
using PetCompanion.Services;

namespace PetCompanion.Controllers
{
    [ApiController]
    [Route("api/v1/[controller]")]
    public class InventoryController : BaseController
    {
        private readonly PetInventoryService inventoryService;
        private readonly ILogger<InventoryController> logger;

        public InventoryController(
            ILogger<InventoryController> logger,
            PetInventoryService inventoryService)
        {
            this.logger = logger;
            this.inventoryService = inventoryService;
        }

        [HttpGet("{petId}")]
        public IActionResult GetInventory(string petId)
        {
            try
            {
                var inventory = inventoryService.GetInventory(petId, userId.ToString());
                return Ok(inventory);
            }
            catch (Exception ex)
            {
                return BadRequest(ex.Message);
            }
        }

        [HttpPut("{petId}/{itemId}/use")]
        public IActionResult UseItem(string petId, int itemId)
        {
            try
            {
                var updatedPet = inventoryService.UseItem(petId, userId.ToString(), itemId);
                return Ok(updatedPet);
            }
            catch (Exception ex)
            {
                return BadRequest(ex.Message);
            }
        }

        [HttpPut("{petId}/{itemId}/equip")]
        public IActionResult EquipItem(string petId, int itemId)
        {
            try
            {
                var updatedPet = inventoryService.EquipItem(petId, userId.ToString(), itemId);
                return Ok(updatedPet);
            }
            catch (Exception ex)
            {
                return BadRequest(ex.Message);
            }
        }

        [HttpPut("{petId}/{itemId}/unequip")]
        public IActionResult UnequipItem(string petId, int itemId)
        {
            try
            {
                var updatedPet = inventoryService.UnequipItem(petId, userId.ToString(), itemId);
                return Ok(updatedPet);
            }
            catch (Exception ex)
            {
                return BadRequest(ex.Message);
            }
        }

        [HttpPut("{petId}/{itemId}/drop")]
        public IActionResult DropItem(string petId, int itemId)
        {
            try
            {
                var updatedPet = inventoryService.DropItem(petId, userId.ToString(), itemId);
                return Ok(updatedPet);
            }
            catch (Exception ex)
            {
                return BadRequest(ex.Message);
            }
        }

        [HttpPost("{petId}/create")]
        public IActionResult AddItem(string petId, [FromBody] AddItemRequest request)
        {
            try
            {
                var updatedPet = inventoryService.AddItemToPet(petId, userId.ToString(), request.ItemId, request.Quantity);
                return Ok(updatedPet);
            }
            catch (Exception ex)
            {
                return BadRequest(ex.Message);
            }
        }
    }

    public class AddItemRequest
    {
        public int ItemId { get; set; }
        public int Quantity { get; set; } = 1;
    }
}
